{% load static %}

{% if errors %}
    <p>
        <b>Error</b> {{ status|safe }}
    </p>
{% else %}

    <p>
        <b>Registered</b> <img src="{{ yes_img }}" alt="True"><br/>
        <b>Name</b> {{ status.name }}<br/>
        <em>Manage this site online at <a href="https://djangoupdater.com/sites/{{ status.site_token }}/">djangoupdater.com</a></em>
    </p>

{% endif %}